@@ -39,6 +39,7 @@ function Badger() {
   var self = this;
 
   self.webRTCAvailable = checkWebRTCBrowserSupport();
+  self.firstPartyDomainPotentiallyRequired = testCookiesFirstPartyDomain();
 
   self.widgetList = [];
   widgetLoader.loadWidgetsFromFile("data/socialwidgets.json", (response) => {
@@ -94,8 +95,8 @@ function Badger() {
   });
 
   /**
-  * WebRTC availability check
-  */
+   * WebRTC availability check
+   */
   function checkWebRTCBrowserSupport() {
     if (!(chrome.privacy && chrome.privacy.network &&
       chrome.privacy.network.webRTCIPHandlingPolicy)) {
@@ -122,6 +123,32 @@ function Badger() {
 
     return available;
   }
+
+  /**
+   * Checks for availability of firstPartyDomain chrome.cookies API parameter.
+   * https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/API/cookies/getAll#Parameters
+   *
+   * firstPartyDomain is required when privacy.websites.firstPartyIsolate is enabled,
+   * and is in Firefox since Firefox 59. (firstPartyIsolate is in Firefox since 58).
+   *
+   * We don't care whether firstPartyIsolate is enabled, but rather whether
+   * firstPartyDomain is supported. Assuming firstPartyDomain is supported,
+   * setting it to null in chrome.cookies.getAll() produces the same result
+   * regardless of the state of firstPartyIsolate.
+   *
+   * firstPartyDomain is not currently supported in Chrome.
+   */
+  function testCookiesFirstPartyDomain() {
+    try {
+      chrome.cookies.getAll({
+        firstPartyDomain: null
+      }, function () {});
+    } catch (ex) {
+      return false;
+    }
+    return true;
+  }
+
 }
 
 Badger.prototype = {
@@ -221,7 +248,10 @@ Badger.prototype = {
     self.tabData = self.tabData || {};
     chrome.tabs.query({}, tabs => {
       tabs.forEach(tab => {
-        self.recordFrame(tab.id, 0, tab.url);
+        // don't record on special browser pages
+        if (!utils.isRestrictedUrl(tab.url)) {
+          self.recordFrame(tab.id, 0, tab.url);
+        }
       });
     });
   },
@@ -503,7 +533,8 @@ Badger.prototype = {
     showIntroPage: true,
     showNonTrackingDomains: false,
     showTrackingDomains: false,
-    socialWidgetReplacementEnabled: true
+    socialWidgetReplacementEnabled: true,
+    widgetReplacementExceptions: [],
   },
 
   /**
@@ -541,6 +572,8 @@ Badger.prototype = {
       Migrations.forgetMistakenlyBlockedDomains,
       Migrations.resetWebRTCIPHandlingPolicy,
       Migrations.enableShowNonTrackingDomains,
+      Migrations.forgetFirstPartySnitches,
+      Migrations.forgetCloudflare,
     ];
 
     for (var i = migrationLevel; i < migrations.length; i++) {
@@ -613,11 +646,11 @@ Badger.prototype = {
       let count = self.getTrackerCount(tab_id);
 
       if (count === 0) {
-        chrome.browserAction.setBadgeBackgroundColor({tabId: tab_id, color: "#00cc00"});
-      } else {
-        chrome.browserAction.setBadgeBackgroundColor({tabId: tab_id, color: "#ec9329"});
+        chrome.browserAction.setBadgeText({tabId: tab_id, text: ""});
+        return;
       }
 
+      chrome.browserAction.setBadgeBackgroundColor({tabId: tab_id, color: "#ec9329"});
       chrome.browserAction.setBadgeText({tabId: tab_id, text: count + ""});
     });
   },
@@ -803,9 +836,11 @@ Badger.prototype = {
       return;
     }
 
-    let iconFilename;
+    let self = this, iconFilename;
+
     // TODO grab hostname from tabData instead
-    if (this.isPrivacyBadgerEnabled(window.extractHostFromURL(tab_url))) {
+    if (!utils.isRestrictedUrl(tab_url) &&
+        self.isPrivacyBadgerEnabled(window.extractHostFromURL(tab_url))) {
       iconFilename = {
         19: chrome.runtime.getURL("icons/badger-19.png"),
         38: chrome.runtime.getURL("icons/badger-38.png")
@@ -824,8 +859,9 @@ Badger.prototype = {
    * Merge data exported from a different badger into this badger's storage.
    *
    * @param {Object} data the user data to merge in
+   * @param {Boolean} [from_migration=false] set when running from a migration to avoid infinite loop
    */
-  mergeUserData: function(data) {
+  mergeUserData: function(data, from_migration) {
     let self = this;
     // The order of these keys is also the order in which they should be imported.
     // It's important that snitch_map be imported before action_map (#1972)
@@ -838,7 +874,9 @@ Badger.prototype = {
 
     // for exports from older Privacy Badger versions:
     // fix yellowlist getting out of sync, remove non-tracking domains, etc.
-    self.runMigrations();
+    if (!from_migration) {
+      self.runMigrations();
+    }
   }
 
 };
@@ -863,26 +901,6 @@ function startBackgroundListeners() {
   chrome.tabs.onActivated.addListener(function (activeInfo) {
     badger.updateBadge(activeInfo.tabId);
   });
-
-  // Listening for Avira Autopilot remote control UI
-  // The Scout browser needs a "emergency off" switch in case Privacy Badger breaks a page.
-  // The Privacy Badger UI will removed from the URL bar into the menu to achieve a cleaner UI in the future.
-  if (chrome.runtime.onMessageExternal) {
-    chrome.runtime.onMessageExternal.addListener(
-      function(request, sender, sendResponse) {
-        // This is the ID of the Avira Autopilot extension, which is the central menu for the scout browser
-        if (sender.id === "ljjneligifenjndbcopdndmddfcjpcng") {
-          if (request.command == "getDisabledSites") {
-            sendResponse({origins: badger.getDisabledSites()});
-          } else if (request.command == "enable") {
-            badger.enablePrivacyBadgerForOrigin(request.origin);
-          } else if (request.command == "disable") {
-            badger.disablePrivacyBadgerForOrigin(request.origin);
-          }
-        }
-      }
-    );
-  }
 }
 
 var badger = window.badger = new Badger();
