@@ -29,16 +29,16 @@ require.scopes.heuristicblocking = (function() {
 // make heuristic obj with utils and storage properties and put the things on it
 function HeuristicBlocker(pbStorage) {
   this.storage = pbStorage;
-}
 
-// TODO roll into tabData? -- 6/10/2019 not for now, since tabData is populated
-// by the synchronous listeners in webrequests.js and tabOrigins is used by the
-// async listeners here; there's no way to enforce ordering of requests among
-// those two. Also, tabData is cleaned up every time a tab is closed, so
-// dangling requests that don't trigger listeners until after the tab closes are
-// impossible to attribute to a tab.
-var tabOrigins = { };
-var tabURLs = { };
+  // TODO roll into tabData? -- 6/10/2019 not for now, since tabData is populated
+  // by the synchronous listeners in webrequests.js and tabOrigins is used by the
+  // async listeners here; there's no way to enforce ordering of requests among
+  // those two. Also, tabData is cleaned up every time a tab is closed, so
+  // dangling requests that don't trigger listeners until after the tab closes are
+  // impossible to attribute to a tab.
+  this.tabOrigins = {};
+  this.tabUrls = {};
+}
 
 HeuristicBlocker.prototype = {
   /**
@@ -95,14 +95,10 @@ HeuristicBlocker.prototype = {
 
   /**
    * Wraps _recordPrevalence for use from webRequest listeners.
-   * Also saves tab (page) origins. TODO Should be handled by tabData instead.
-   *
-   * Called from performance-critical webRequest listeners!
    * Use updateTrackerPrevalence for non-webRequest initiated bookkeeping.
    *
-   * @param details are those from onBeforeSendHeaders
+   * @param {Object} details request/response details
    * @param {Boolean} check_for_cookie_share whether to check for cookie sharing
-   * @returns {*}
    */
   heuristicBlockingAccounting: function (details, check_for_cookie_share) {
     // ignore requests that are outside a tabbed window
@@ -110,39 +106,39 @@ HeuristicBlocker.prototype = {
       return {};
     }
 
-    let fqdn = (new URI(details.url)).host,
-      origin = window.getBaseDomain(fqdn);
+    let self = this,
+      request_host = (new URI(details.url)).host,
+      request_origin = window.getBaseDomain(request_host);
 
     // if this is a main window request, update tab data and quit
     if (details.type == "main_frame") {
-      tabOrigins[details.tabId] = origin;
-      tabURLs[details.tabId] = details.url;
+      self.tabOrigins[details.tabId] = request_origin;
+      self.tabUrls[details.tabId] = details.url;
       return {};
     }
 
-    let tab_origin = tabOrigins[details.tabId],
-      self = this;
+    let tab_origin = self.tabOrigins[details.tabId];
 
     // ignore first-party requests
-    if (!tab_origin || origin == tab_origin) {
+    if (!tab_origin || !utils.isThirdPartyDomain(request_origin, tab_origin)) {
       return {};
     }
 
     // short-circuit if we already observed this origin tracking on this site
-    let firstParties = self.storage.getBadgerStorageObject('snitch_map').getItem(origin);
+    let firstParties = self.storage.getBadgerStorageObject('snitch_map').getItem(request_origin);
     if (firstParties && firstParties.indexOf(tab_origin) > -1) {
       return {};
     }
 
     // abort if we already made a decision for this FQDN
-    let action = self.storage.getAction(fqdn);
+    let action = self.storage.getAction(request_host);
     if (action != constants.NO_TRACKING && action != constants.ALLOW) {
       return {};
     }
 
     // check if there are tracking cookies
-    if (hasCookieTracking(details, origin)) {
-      self._recordPrevalence(fqdn, origin, tab_origin);
+    if (hasCookieTracking(details, request_origin)) {
+      self._recordPrevalence(request_host, request_origin, tab_origin);
       return {};
     }
 
@@ -150,12 +146,18 @@ HeuristicBlocker.prototype = {
     if (check_for_cookie_share && details.type == 'image' && details.url.indexOf('?') > -1) {
       // get all cookies for the top-level frame and pass those to the
       // cookie-share accounting function
-      let tab_url = tabURLs[details.tabId];
-      chrome.cookies.getAll({
+      let tab_url = self.tabUrls[details.tabId];
+
+      let config = {
         url: tab_url
-      }, function(cookies) {
+      };
+      if (badger.firstPartyDomainPotentiallyRequired) {
+        config.firstPartyDomain = null;
+      }
+
+      chrome.cookies.getAll(config, function (cookies) {
         if (cookies.length >= 1) {
-          self.pixelCookieShareAccounting(tab_url, tab_origin, details.url, fqdn, origin, cookies);
+          self.pixelCookieShareAccounting(tab_url, tab_origin, details.url, request_host, request_origin, cookies);
         }
       });
     }
@@ -173,7 +175,7 @@ HeuristicBlocker.prototype = {
    * @param cookies are the result of chrome.cookies.getAll()
    * @returns {*}
    */
-  pixelCookieShareAccounting: function (tab_url, tab_origin, request_url, request_fqdn, request_origin, cookies) {
+  pixelCookieShareAccounting: function (tab_url, tab_origin, request_url, request_host, request_origin, cookies) {
     let params = (new URL(request_url)).searchParams,
       TRACKER_ENTROPY_THRESHOLD = 33,
       MIN_STR_LEN = 8;
@@ -242,10 +244,10 @@ HeuristicBlocker.prototype = {
           // our threshold, record the tracking action and exit the function.
           let entropy = utils.estimateMaxEntropy(s);
           if (entropy > TRACKER_ENTROPY_THRESHOLD) {
-            log("Found high-entropy cookie share from", tab_origin, "to", request_fqdn,
+            log("Found high-entropy cookie share from", tab_origin, "to", request_host,
               ":", entropy, "bits\n  cookie:", cookie.name, '=', cookie.value,
               "\n  arg:", key, "=", value, "\n  substring:", s);
-            this._recordPrevalence(request_fqdn, request_origin, tab_origin);
+            this._recordPrevalence(request_host, request_origin, tab_origin);
             return;
           }
         }
