@@ -261,6 +261,84 @@ exports.Migrations= {
     }
   },
 
+  forgetFirstPartySnitches: function (badger) {
+    console.log("Removing first parties from snitch map...");
+    let snitchMap = badger.storage.getBadgerStorageObject("snitch_map"),
+      actionMap = badger.storage.getBadgerStorageObject("action_map"),
+      snitchClones = snitchMap.getItemClones(),
+      actionClones = actionMap.getItemClones(),
+      correctedSites = {};
+
+    for (let domain in snitchClones) {
+      // creates new array of domains checking against the isThirdParty utility
+      let newSnitches = snitchClones[domain].filter(
+        item => utils.isThirdPartyDomain(item, domain));
+
+      if (newSnitches.length) {
+        correctedSites[domain] = newSnitches;
+      }
+    }
+
+    // clear existing maps and then use mergeUserData to rebuild them
+    actionMap.updateObject({});
+    snitchMap.updateObject({});
+
+    const data = {
+      snitch_map: correctedSites,
+      action_map: actionClones
+    };
+
+    // pass in boolean 2nd parameter to flag that it's run in a migration, preventing infinite loop
+    badger.mergeUserData(data, true);
+  },
+
+  forgetCloudflare: function (badger) {
+    let config = {
+      name: '__cfduid'
+    };
+    if (badger.firstPartyDomainPotentiallyRequired) {
+      config.firstPartyDomain = null;
+    }
+
+    chrome.cookies.getAll(config, function (cookies) {
+      console.log("Forgetting Cloudflare domains ...");
+
+      let actionMap = badger.storage.getBadgerStorageObject("action_map"),
+        actionClones = actionMap.getItemClones(),
+        snitchMap = badger.storage.getBadgerStorageObject("snitch_map"),
+        snitchClones = snitchMap.getItemClones(),
+        correctedSites = {},
+        // assume the tracking domains seen on these sites are all Cloudflare
+        cfduidFirstParties = new Set();
+
+      cookies.forEach(function (cookie) {
+        // get the base domain (also removes the leading dot)
+        cfduidFirstParties.add(window.getBaseDomain(cookie.domain));
+      });
+
+      for (let domain in snitchClones) {
+        let newSnitches = snitchClones[domain].filter(
+          item => !cfduidFirstParties.has(item));
+
+        if (newSnitches.length) {
+          correctedSites[domain] = newSnitches;
+        }
+      }
+
+      // clear existing maps and then use mergeUserData to rebuild them
+      actionMap.updateObject({});
+      snitchMap.updateObject({});
+
+      const data = {
+        snitch_map: correctedSites,
+        action_map: actionClones
+      };
+
+      // pass in boolean 2nd parameter to flag that it's run in a migration, preventing infinite loop
+      badger.mergeUserData(data, true);
+    });
+  },
+
 };
 
 
