@@ -7,33 +7,64 @@ require.scopes.multiDomainFP = (function() {
 var multiDomainFirstPartiesArray = [
   ["1800contacts.com", "800contacts.com"],
   ["37signals.com", "basecamp.com", "basecamphq.com", "highrisehq.com"],
-  [
-    "abcnews.com",
-    "6abc.com",
-    "abc7.com",
-    "abc7ny.com",
-
-    "go.com",
-
-    "espn.com",
-    "espncdn.com",
-
-    "espn.com.au",
-    "espn.com.br",
-    "espn.co.uk",
-
-    "espncricinfo.com",
-
-    "espnfc.com",
-    "espnfc.us",
-
-    "fivethirtyeight.com",
-
-    "disney.com",
-    "disneymoviesanywhere.com",
-    "dadt.com",
-  ],
+  ["9gag.com", "9cache.com"],
   ["accountonline.com", "citi.com", "citibank.com", "citicards.com", "citibankonline.com"],
+  [
+    "adidas-group.com",
+
+    "adidas.ae",
+    "adidas.at",
+    "adidas.be",
+    "adidas.ca",
+    "adidas.ch",
+    "adidas.cl",
+    "adidas.cn",
+    "adidas.co",
+    "adidas.co.id",
+    "adidas.co.in",
+    "adidas.co.kr",
+    "adidas.com",
+    "adidas.com.ar",
+    "adidas.com.au",
+    "adidas.com.br",
+    "adidas.com.co",
+    "adidas.com.hk",
+    "adidas.com.my",
+    "adidas.com.om",
+    "adidas.com.pe",
+    "adidas.com.ph",
+    "adidas.com.qa",
+    "adidas.com.sa",
+    "adidas.com.sg",
+    "adidas.com.tr",
+    "adidas.com.tw",
+    "adidas.com.vn",
+    "adidas.co.nz",
+    "adidas.co.th",
+    "adidas.co.uk",
+    "adidas.co.za",
+    "adidas.cz",
+    "adidas.de",
+    "adidas.dk",
+    "adidas.es",
+    "adidas.fi",
+    "adidas.fr",
+    "adidas.gr",
+    "adidas.hu",
+    "adidas.ie",
+    "adidas.it",
+    "adidas.jp",
+    "adidas.mx",
+    "adidas.nl",
+    "adidas.no",
+    "adidas.pe",
+    "adidas.pl",
+    "adidas.pt",
+    "adidas.ru",
+    "adidas.se",
+    "adidas.sk",
+    "adidas.us",
+  ],
   [
     "adobe.com",
     "adobeexchange.com",
@@ -44,6 +75,86 @@ var multiDomainFirstPartiesArray = [
     "myportfolio.com",
     "typekit.com",
   ],
+  [
+    "airbnb.com",
+
+    "airbnb.ae",
+    "airbnb.al",
+    "airbnb.am",
+    "airbnb.at",
+    "airbnb.az",
+    "airbnb.ba",
+    "airbnb.be",
+    "airbnb.ca",
+    "airbnb.cat",
+    "airbnb.ch",
+    "airbnb.cl",
+    "airbnb.co.cr",
+    "airbnb.co.id",
+    "airbnb.co.il",
+    "airbnb.co.in",
+    "airbnb.co.kr",
+    "airbnb.com.ar",
+    "airbnb.com.au",
+    "airbnb.com.bo",
+    "airbnb.com.br",
+    "airbnb.com.bz",
+    "airbnb.com.co",
+    "airbnb.com.ec",
+    "airbnb.com.ee",
+    "airbnb.com.gt",
+    "airbnb.com.hk",
+    "airbnb.com.hn",
+    "airbnb.com.hr",
+    "airbnb.com.kh",
+    "airbnb.com.mt",
+    "airbnb.com.my",
+    "airbnb.com.ni",
+    "airbnb.com.pa",
+    "airbnb.com.pe",
+    "airbnb.com.ph",
+    "airbnb.com.py",
+    "airbnb.com.ro",
+    "airbnb.com.sg",
+    "airbnb.com.sv",
+    "airbnb.com.tr",
+    "airbnb.com.tw",
+    "airbnb.com.ua",
+    "airbnb.com.vn",
+    "airbnb.co.nz",
+    "airbnb.co.uk",
+    "airbnb.co.ve",
+    "airbnb.co.za",
+    "airbnb.cz",
+    "airbnb.de",
+    "airbnb.dk",
+    "airbnb.es",
+    "airbnb.fi",
+    "airbnb.fr",
+    "airbnb.gr",
+    "airbnb.gy",
+    "airbnb.hu",
+    "airbnb.ie",
+    "airbnb.is",
+    "airbnb.it",
+    "airbnb.jp",
+    "airbnb.la",
+    "airbnb.lt",
+    "airbnb.lu",
+    "airbnb.lv",
+    "airbnb.me",
+    "airbnb.mx",
+    "airbnb.nl",
+    "airbnb.no",
+    "airbnb.pl",
+    "airbnb.pt",
+    "airbnb.rs",
+    "airbnb.ru",
+    "airbnb.se",
+    "airbnb.si",
+
+    "muscache.com",
+  ],
   [
     "alibaba.com",
 
@@ -55,6 +166,7 @@ var multiDomainFirstPartiesArray = [
     "alicdn.com",
     "alicdn.net",
     "aliexpress.com",
+    "aliexpress.ru",
     "aligames.com",
     "alihealth.cn",
     "alihive.com",
@@ -126,7 +238,6 @@ var multiDomainFirstPartiesArray = [
     "aliloan.com",
     "alipay-cloud.com",
     "alipay.cn",
-    "alipay.com",
     "alipay-eco.com",
     "alipay.hk",
     "alipayplus.com",
@@ -151,36 +262,71 @@ var multiDomainFirstPartiesArray = [
     "zamcs.com",
     "zhisheng.com",
     "zmxy.com.cn",
+
+    "lazada.com",
+
+    "lazada.co.id",
+    "lazada.com.my",
+    "lazada.com.ph",
+    "lazada.co.th",
+    "lazada.sg",
+    "lazada.vn",
   ],
   ["allstate.com", "myallstate.com"],
   ["altra.org", "altraonline.org"],
   [
     "amazon.com",
 
+    "amazon.ae",
     "amazon.ca",
+    "amazon.cn",
     "amazon.co.jp",
     "amazon.com.au",
+    "amazon.com.br",
     "amazon.com.mx",
+    "amazon.com.sg",
+    "amazon.com.tr",
     "amazon.co.uk",
     "amazon.de",
     "amazon.es",
     "amazon.fr",
     "amazon.in",
     "amazon.it",
+    "amazon.nl",
 
     "audible.com",
-
+    "audible.co.jp",
+    "audible.com.au",
     "audible.co.uk",
     "audible.de",
+    "audible.fr",
     "audible.in",
+    "audible.it",
 
     "6pm.com",
+    "acx.com",
+    "amazoninspire.com",
+    "aws.training",
+    "brilliancepublishing.com",
+    "comixology.com",
+    "createspace.com",
+    "dpreview.com",
+    "eastdane.com",
+    "fabric.com",
+    "goodreads.com",
     "imdb.com",
+    "pillpack.com",
     "primevideo.com",
     "shopbop.com",
-    "twitch.tv",
+    "wholefoodsmarket.com",
+    "woot.com",
     "zappos.com",
 
+    "twitch.tv",
+    "ext-twitch.tv",
+    "jtvnw.net",
+    "ttvnw.net",
+
     "amazonpay.com",
     "media-amazon.com",
     "ssl-images-amazon.com",
@@ -254,6 +400,7 @@ var multiDomainFirstPartiesArray = [
     "kleinezeitung.at",
     "vn.at",
     "kurier.at",
+    "schautv.at",
     "nachrichten.at",
     "derstandard.at",
     "sn.at",
@@ -263,11 +410,30 @@ var multiDomainFirstPartiesArray = [
     "tt.com",
     "diepresse.com",
   ],
-  ["apple.com", "icloud.com"],
+  ["apple.com", "icloud.com", "icloud.com.cn", "cdn-apple.com"],
   ["applefcu.org", "applefcuonline.org"],
   ["archive.org", "openlibrary.org"],
+  [
+    "atlassian.com",
+
+    "atlassian.io",
+    "atlassian.net",
+    "bitbucket.org",
+    "customercase.com",
+    "enso.me",
+    "hipchat.com",
+    "jira.com",
+    "statuspage.io",
+    "stride.com",
+    "trello.com",
+
+    "atl-paas.net",
+  ],
+  ["att.com", "att.tv"],
   [
     "autodesk.com",
+
+    "autodesk.io",
     "autodesk.net",
     "circuits.io",
     "tinkercad.com",
@@ -314,25 +480,19 @@ var multiDomainFirstPartiesArray = [
   ["bancomer.com", "bancomer.com.mx", "bbvanet.com.mx"],
   ["bankofamerica.com", "bofa.com", "mbna.com", "usecfo.com"],
   ["bank-yahav.co.il", "bankhapoalim.co.il"],
+  [
+    "bauermedia.co.uk",
+
+    "carmagazine.co.uk",
+    "motorcyclenews.com",
+    "parkers.co.uk",
+
+    "bauersecure.com",
+  ],
   ["bbc.co.uk", "bbc.com", "bbci.co.uk"],
   ["belkin.com", "seedonk.com"],
-  [
-    "bitbucket.org",
-
-    "atlassian.com",
-    "atlassian.io",
-    "atlassian.net",
-
-    "customercase.com",
-    "enso.me",
-    "hipchat.com",
-    "jira.com",
-    "statuspage.io",
-    "stride.com",
-    "trello.com",
-
-    "atl-paas.net",
-  ],
+  ["bhphotovideo.com", "bandh.com", "bhphoto.com", "bnh.com"],
+  ["bilibili.com", "acgvideo.com", "biliapi.net", "biliapi.com", "biligame.com", "hdslb.com"],
   ["blizzard.com", "battle.net", "worldofwarcraft.com"],
   ["bloomberg.com", "bbthat.com", "bwbx.io"],
   ["booking.com", "bstatic.com"],
@@ -380,15 +540,156 @@ var multiDomainFirstPartiesArray = [
     "zdnet.com",
   ],
   ["cb2.com", "crateandbarrel.com"],
+  [
+    "ccmbenchmark.com",
+
+    "linternaute.com",
+    "journaldesfemmes.fr",
+    "journaldunet.com",
+    "commentcamarche.net",
+
+    "ccmbg.com",
+  ],
   ["century21.com", "21online.com"],
   ["chart.io", "chartio.com"],
+  ["cms.gov", "medicare.gov", "mymedicare.gov"],
   ["concur.com", "concursolutions.com"],
   ["cox.com", "cox.net"],
   ["cricketwireless.com", "aiowireless.com"],
   ["ctrip.com", "c-ctrip.com", "trip.com"],
   ["dcu.org", "dcu-online.org"],
-  ["diapers.com", "soap.com", "wag.com", "yoyo.com", "beautybar.com", "casa.com", "afterschool.com", "vine.com", "bookworm.com", "look.com", "vinemarket.com"],
   ["dictionary.com", "thesaurus.com", "sfdict.com"],
+  [
+    "digikey.com",
+
+    "digikey.ae",
+    "digikey.am",
+    "digikey.at",
+    "digikey.ba",
+    "digikey.be",
+    "digikey.bg",
+    "digikey.bo",
+    "digikey.by",
+    "digikey.ca",
+    "digikey.ch",
+    "digikey.cl",
+    "digikey.cn",
+    "digikey.co.id",
+    "digikey.co.il",
+    "digikey.com.ar",
+    "digikey.com.au",
+    "digikey.com.br",
+    "digikey.com.cn",
+    "digikey.com.co",
+    "digikey.com.cy",
+    "digikey.com.eg",
+    "digikey.com.gt",
+    "digikey.com.hr",
+    "digikey.com.jm",
+    "digikey.com.lb",
+    "digikey.com.mk",
+    "digikey.com.mx",
+    "digikey.com.pa",
+    "digikey.com.tr",
+    "digikey.com.ua",
+    "digikey.com.uy",
+    "digikey.com.ve",
+    "digikey.co.nz",
+    "digikey.co.th",
+    "digikey.co.uk",
+    "digikey.co.za",
+    "digikey.cr",
+    "digikey.cz",
+    "digikey.de",
+    "digikey.dk",
+    "digikey.do",
+    "digikey.ec",
+    "digikey.ee",
+    "digikey.es",
+    "digikey.fi",
+    "digikey.fr",
+    "digikey.gr",
+    "digikey.hk",
+    "digikey.hu",
+    "digikey.ie",
+    "digikey.in",
+    "digikey.is",
+    "digikey.it",
+    "digikey.jp",
+    "digikey.kr",
+    "digikey.lk",
+    "digikey.lt",
+    "digikey.lu",
+    "digikey.lv",
+    "digikey.ma",
+    "digikey.md",
+    "digikey.my",
+    "digikey.nl",
+    "digikey.no",
+    "digikey.pe",
+    "digikey.ph",
+    "digikey.pk",
+    "digikey.pl",
+    "digikey.pr",
+    "digikey.pt",
+    "digikey.ro",
+    "digikey.rs",
+    "digikey.ru",
+    "digikey.se",
+    "digikey.sg",
+    "digikey.si",
+    "digikey.sk",
+    "digikey.tn",
+    "digikey.tw",
+    "digikey.vn",
+  ],
+  [
+    "digitec.ch",
+
+    "galaxus.ch",
+    "galaxus.de",
+    "galaxus.fr",
+
+    "digitecgalaxus.ch",
+  ],
+  [
+    "directferries.com",
+
+    "directferries.at",
+    "directferries.be",
+    "directferries.ca",
+    "directferries.ch",
+    "directferries.cn",
+    "directferries.co.id",
+    "directferries.co.kr",
+    "directferries.com.au",
+    "directferries.com.tr",
+    "directferries.com.ua",
+    "directferries.co.nz",
+    "directferries.co.uk",
+    "directferries.cz",
+    "directferries.de",
+    "directferries.dk",
+    "directferries.es",
+    "directferries.fi",
+    "directferries.fr",
+    "directferries.gr",
+    "directferries.ie",
+    "directferries.it",
+    "directferries.jp",
+    "directferries.kr",
+    "directferries.ma",
+    "directferries.nl",
+    "directferries.no",
+    "directferries.nz",
+    "directferries.pl",
+    "directferries.pt",
+    "directferries.ro",
+    "directferries.ru",
+    "directferries.se",
+    "directferries.sk",
+    "directferries.xyz",
+  ],
   ["discountbank.co.il", "telebank.co.il"],
   ["discover.com", "discovercard.com"],
   [
@@ -409,6 +710,7 @@ var multiDomainFirstPartiesArray = [
     "ed.nl",
     "gelderlander.nl",
     "hln.be",
+    "humo.be",
     "parool.nl",
     "persgroepinternational.be",
     "persgroepinternational.com",
@@ -426,6 +728,7 @@ var multiDomainFirstPartiesArray = [
   ["ea.com", "origin.com", "play4free.com", "tiberiumalliance.com"],
   [
     "ebay.com",
+    "ebayinc.com",
 
     "ebay.at",
     "ebay.be",
@@ -445,11 +748,13 @@ var multiDomainFirstPartiesArray = [
     "ebay.nl",
     "ebay.ph",
     "ebay.pl",
+    "vivanuncios.com.mx",
 
     "ebaydesc.com",
     "ebayimg.com",
     "ebayrtm.com",
     "ebaystatic.com",
+    "ebay-us.com",
   ],
   ["elsevier.com", "sciencedirect.com", "sciencedirectassets.com"],
   [
@@ -470,6 +775,7 @@ var multiDomainFirstPartiesArray = [
     "citer.fr",
 
     "ehi.com",
+    "ehiaws.com",
 
     "enterprise.ca",
     "enterprise.ch",
@@ -522,6 +828,14 @@ var multiDomainFirstPartiesArray = [
     "nationalcar.mobi",
 
     "onewaygo.de",
+
+    "alamo-np.ca",
+    "alamo-np.com",
+    "alamo-np.co.uk",
+    "alamo-np.de",
+    "alamo-np.es",
+    "alamo-np.fr",
+    "alamo-np.ie",
   ],
   [
     "expedia.com",
@@ -603,7 +917,43 @@ var multiDomainFirstPartiesArray = [
     "mrjet.dk",
   ],
   ["express-scripts.com", "medcohealth.com"],
-  ["facebook.com", "fbcdn.com", "fbcdn.net", "fbsbx.com", "facebook.net", "messenger.com"],
+  [
+    "facebook.com",
+
+    "messenger.com",
+    "workplace.com",
+
+    "oculus.com",
+    "oculuscdn.com",
+    "oculusrift.com",
+    "oculusvr.com",
+    "powersunitedvr.com",
+
+    "facebook.net",
+    "fbcdn.com",
+    "fbcdn.net",
+    "fbsbx.com",
+  ],
+  [
+    "faithlife.com",
+
+    "biblescreen.com",
+    "biblestudymagazine.com",
+    "biblia.com",
+    "didaktikosjournal.com",
+    "faithlifetv.com",
+    "kirkdalepress.com",
+    "lexhampress.com",
+    "logos.com",
+    "ministrytracker.com",
+    "proclaimonline.com",
+    "verbum.com",
+
+    "bibliacdn.com",
+    "faithlifecdn.com",
+    "faithlifesitescdn.com",
+    "logoscdn.com",
+  ],
   [
     "fandom.com",
     "fandom-dev.pl",
@@ -620,6 +970,25 @@ var multiDomainFirstPartiesArray = [
     "wikia-services.com",
     "wikia-staging.com",
   ],
+  [
+    "fastcompany.com",
+
+    "fastcocreate.com",
+    "fastcodesign.com",
+    "fastcoexist.com",
+    "fastcolabs.com",
+    "fast-co.net",
+    "fcimpactcouncil.com",
+    "inc.com",
+    "innovationuncensored.com",
+    "mansueto.com",
+    "mvdigitalmedia.com",
+    "mvlicensing.com",
+    "nativguard.com",
+    "retirementcomm.com",
+
+    "fastcompany.net",
+  ],
   ["fastmail.com", "fastmailusercontent.com"],
   ["firefox.com", "firefoxusercontent.com", "mozilla.org"],
   ["foxnews.com", "foxbusiness.com", "fncstatic.com"],
@@ -752,7 +1121,6 @@ var multiDomainFirstPartiesArray = [
     "google.com.mx",
     "google.com.my",
     "google.com.na",
-    "google.com.nf",
     "google.com.ng",
     "google.com.ni",
     "google.com.np",
@@ -818,7 +1186,6 @@ var multiDomainFirstPartiesArray = [
     "google.gg",
     "google.gl",
     "google.gm",
-    "google.gp",
     "google.gr",
     "google.gy",
     "google.hn",
@@ -876,7 +1243,6 @@ var multiDomainFirstPartiesArray = [
     "google.st",
     "google.td",
     "google.tg",
-    "google.tk",
     "google.tl",
     "google.tm",
     "google.tn",
@@ -890,9 +1256,9 @@ var multiDomainFirstPartiesArray = [
     "storage.googleapis.com",
     "www.googleapis.com",
 
+    "nest.com",
     "nestpowerproject.withgoogle.com",
   ],
-  ["gotomeeting.com", "citrixonline.com"],
   [
     "gray.tv",
 
@@ -1087,60 +1453,460 @@ var multiDomainFirstPartiesArray = [
   ],
   ["hvfcu.org", "hvfcuonline.org"],
   ["ign.fr", "geoportail.gouv.fr", "geoportail-urbanisme.gouv.fr", "cartoradio.fr", "ignrando.fr"],
+  [
+    "impresa.pt",
+
+    "blitz.pt",
+    "expresso.pt",
+    "famashow.pt",
+    "impresamediacriativa.pt",
+    "sapo.pt",
+    "siccaras.pt",
+    "sickapa.pt",
+    "sicmulher.pt",
+    "sicnoticias.pt",
+    "sic.pt",
+    "sicradical.pt",
+    "smack.pt",
+    "tribunaexpresso.pt",
+    "volantesic.pt",
+  ],
+  ["independent.co.uk", "indy100.com"],
+  [
+    "jd.com",
+    "3.cn",
+    "360buy.com",
+    "360buyimg.com",
+    "7fresh.com",
+    "baitiao.com",
+    "caiyu.com",
+    "chinabank.com.cn",
+    "jd.co.th",
+    "jd.hk",
+    "jd.id",
+    "jd.ru",
+    "jdpay.com",
+    "jdx.com",
+    "joybuy.com",
+    "joybuy.es",
+    "ocwms.com",
+    "paipai.com",
+    "toplife.com",
+    "wangyin.com",
+    "yhd.com",
+    "yihaodianimg.com",
+    "yiyaojd.com",
+    "yizhitou.com",
+  ],
+  [
+    "kayak.com",
+
+    "kayak.ae",
+    "kayak.cat",
+    "kayak.ch",
+    "kayak.cl",
+    "kayak.co.id",
+    "kayak.co.in",
+    "kayak.co.jp",
+    "kayak.co.kr",
+    "kayak.com.ar",
+    "kayak.com.au",
+    "kayak.com.br",
+    "kayak.com.co",
+    "kayak.com.hk",
+    "kayak.com.mx",
+    "kayak.com.my",
+    "kayak.com.pe",
+    "kayak.com.ph",
+    "kayak.com.tr",
+    "kayak.co.th",
+    "kayak.co.uk",
+    "kayak.de",
+    "kayak.dk",
+    "kayak.es",
+    "kayak.eu",
+    "kayak.fr",
+    "kayak.ie",
+    "kayak.it",
+    "kayak.nl",
+    "kayak.no",
+    "kayak.ph",
+    "kayak.pl",
+    "kayak.pt",
+    "kayak.qa",
+    "kayak.ru",
+    "kayak.se",
+    "kayak.sg",
+
+    "checkfelix.com",
+    "checkfelix.co.uk",
+    "checkfelix.es",
+    "checkfelix.fr",
+    "checkfelix.it",
+
+    "momondo.at",
+    "momondo.be",
+    "momondo.by",
+    "momondo.ca",
+    "momondo.ch",
+    "momondo.cl",
+    "momondo.com",
+    "momondo.com.ar",
+    "momondo.com.au",
+    "momondo.com.br",
+    "momondo.com.cn",
+    "momondo.com.co",
+    "momondo.com.pe",
+    "momondo.com.tr",
+    "momondo.co.nz",
+    "momondo.co.uk",
+    "momondo.co.za",
+    "momondo.cz",
+    "momondo.de",
+    "momondo.dk",
+    "momondo.ee",
+    "momondo.es",
+    "momondo.fi",
+    "momondo.fr",
+    "momondogroup.com",
+    "momondo.hk",
+    "momondo.ie",
+    "momondo.in",
+    "momondo.it",
+    "momondo.kz",
+    "momondo.lt",
+    "momondo.mx",
+    "momondo.net",
+    "momondo.nl",
+    "momondo.no",
+    "momondo.pl",
+    "momondo.pro",
+    "momondo.pt",
+    "momondo.ro",
+    "momondo.ru",
+    "momondo.se",
+    "momondo.tw",
+    "momondo.ua",
+
+    "mundi.com.br",
+
+    "speedfares.com",
+
+    "swoodoo.at",
+    "swoodoo.ch",
+    "swoodoo.com",
+
+    "r9cdn.net",
+  ],
+  ["kiwi.com", "skypicker.com"],
+  [
+    "kogan.com",
+
+    "dicksmith.com.au",
+    "dicksmith.co.nz",
+    "koganinternet.com.au",
+    "koganmobile.co.nz",
+    "kogansuper.com.au",
+    "kogantravel.com",
+  ],
+  ["livejournal.com", "livejournal.net", "lj-toys.com"],
   ["lnk.to", "tix.to", "tck.to", "ticket.to", "linkfire.com", "assetlab.io", "linkfire.co", "lnkfi.re"],
-  ["logmein.com", "logme.in"],
+  [
+    "logmeininc.com",
+
+    "citrixonline.com",
+    "gotomeeting.com",
+    "gotomeet.me",
+    "gotomypc.com",
+    "gotostage.com",
+    "gotowebinar.com",
+    "logme.in",
+    "logmein.com",
+
+    "getgo.com",
+  ],
   ["macys.com", "macysassets.com"],
+  [
+    "mafra.cz",
+
+    "idnes.cz",
+    "lidovky.cz",
+    "expres.cz",
+
+    "1gr.cz",
+  ],
   ["mandtbank.com", "mtb.com"],
   ["mathletics.com", "mathletics.com.au", "mathletics.co.uk"],
   ["mdsol.com", "imedidata.com"],
+  [
+    "mediamarktsaturn.com",
+
+    "mediamarkt.at",
+    "mediamarkt.be",
+    "mediamarkt.ch",
+    "mediamarkt.com.tr",
+    "mediamarkt.de",
+    "mediamarkt.es",
+    "mediamarkt.gr",
+    "mediamarkt.hu",
+    "mediamarkt.nl",
+    "mediamarkt.se",
+
+    "saturn.at",
+    "saturn.de",
+    "saturn.lu",
+
+    "redblue.de",
+
+    "mediamarkt.pl",
+    "redcoon.pl",
+    "saturn.pl",
+    "ms-online.pl",
+  ],
   ["meetup.com", "meetupstatic.com"],
-  ["mercadolivre.com", "mercadolivre.com.br", "mercadolibre.com", "mercadolibre.com.ar", "mercadolibre.com.mx"],
+  [
+    "mercadolibre.com",
+
+    "mercadolibre.cl",
+    "mercadolibre.co.cr",
+    "mercadolibre.com.ar",
+    "mercadolibre.com.bo",
+    "mercadolibre.com.co",
+    "mercadolibre.com.do",
+    "mercadolibre.com.ec",
+    "mercadolibre.com.gt",
+    "mercadolibre.com.hn",
+    "mercadolibre.com.mx",
+    "mercadolibre.com.ni",
+    "mercadolibre.com.pa",
+    "mercadolibre.com.pe",
+    "mercadolibre.com.py",
+    "mercadolibre.com.sv",
+    "mercadolibre.com.uy",
+    "mercadolibre.com.ve",
+    "mercadolivre.com",
+    "mercadolivre.com.br",
+
+    "mercadopago.com",
+    "mercadopago.com.ar",
+    "mercadopago.com.br",
+    "mercadopago.com.co",
+    "mercadopago.com.mx",
+
+    "mercadoshops.com",
+    "mercadoshops.cl",
+    "mercadoshops.com.ar",
+    "mercadoshops.com.br",
+    "mercadoshops.com.co",
+    "mercadoshops.com.mx",
+    "mercadoshops.com.ve",
+
+    "mercadoclics.com",
+    "mlstatic.com",
+  ],
+  [
+    "mercedes-benz.com",
+
+    "mercedes-benz-africa.com",
+    "mercedes-benz-asia.com",
+    "mercedes-benz.at",
+    "mercedes-benz.ba",
+    "mercedes-benz.be",
+    "mercedes-benz.bg",
+    "mercedes-benz.ca",
+    "mercedes-benz.ch",
+    "mercedes-benz.cl",
+    "mercedes-benz.co.id",
+    "mercedes-benz.co.in",
+    "mercedes-benz.co.jp",
+    "mercedes-benz.co.kr",
+    "mercedes-benz.com.ar",
+    "mercedes-benz.com.au",
+    "mercedes-benz.com.br",
+    "mercedes-benz.com.cn",
+    "mercedes-benz.com.co",
+    "mercedes-benz.com.cy",
+    "mercedes-benz.com.eg",
+    "mercedes-benz.com.gt",
+    "mercedes-benz.com.hk",
+    "mercedes-benz.com.lk",
+    "mercedes-benz.com.mt",
+    "mercedes-benz.com.mx",
+    "mercedes-benz.com.my",
+    "mercedes-benz.com.pe",
+    "mercedes-benz.com.ph",
+    "mercedes-benz.com.sg",
+    "mercedes-benz.com.tr",
+    "mercedes-benz.com.tt",
+    "mercedes-benz.com.tw",
+    "mercedes-benz.com.uy",
+    "mercedes-benz.com.vn",
+    "mercedes-benz.co.nz",
+    "mercedes-benz.co.th",
+    "mercedes-benz.co.uk",
+    "mercedes-benz.co.ve",
+    "mercedes-benz.co.za",
+    "mercedes-benz.cz",
+    "mercedes-benz.de",
+    "mercedes-benz.dk",
+    "mercedes-benz-eastern-europe.com",
+    "mercedes-benz.ee",
+    "mercedes-benz.es",
+    "mercedes-benz.fi",
+    "mercedes-benz.fr",
+    "mercedes-benz.gr",
+    "mercedes-benz.hr",
+    "mercedes-benz.hu",
+    "mercedes-benz.ie",
+    "mercedes-benz.is",
+    "mercedes-benz.it",
+    "mercedes-benz.li",
+    "mercedes-benz.lt",
+    "mercedes-benz.lu",
+    "mercedes-benz.lv",
+    "mercedes-benz-mena.com",
+    "mercedes-benz.nl",
+    "mercedes-benz.no",
+    "mercedes-benz-north-cyprus.com",
+    "mercedes-benz.pl",
+    "mercedes-benz.pt",
+    "mercedes-benz.ro",
+    "mercedes-benz.rs",
+    "mercedes-benz.ru",
+    "mercedes-benz.se",
+    "mercedes-benz.si",
+    "mercedes-benz.sk",
+    "mercedes-benz.ua",
+  ],
   ["mi.com", "xiaomi.com"],
   [
     "microsoft.com",
 
     "1drv.ms",
+    "aadrm.com",
+    "acompli.net",
+    "adbureau.net",
+    "adecn.com",
+    "aka.ms",
+    "aquantive.com",
     "aspnetcdn.com",
+    "assets-yammer.com",
     "azure.com",
     "azureedge.net",
     "azure.net",
+    "azurerms.com",
     "bing.com",
     "bing.net",
+    "cloudappsecurity.com",
     "dynamics.com",
+    "gamesforwindows.com",
+    "getgamesmart.com",
     "gfx.ms",
     "healthvault.com",
+    "hockeyapp.net",
     "hotmail.com",
+    "ieaddons.com",
+    "iegallery.com",
     "live.com",
+    "live.net",
+    "lync.com",
+    "microsoftalumni.com",
+    "microsoftalumni.org",
+    "microsoftazuread-sso.com",
+    "microsoftedgeinsiders.com",
     "microsoftonline.com",
+    "microsoftonline-p.com",
+    "microsoftonline-p.net",
     "microsoftstore.com",
     "microsoftstream.com",
+    "msads.net",
+    "msappproxy.net",
+    "msauthimages.net",
+    "msecnd.net",
+    "msedge.net",
+    "msftidentity.com",
+    "msft.net",
+    "msidentity.com",
     "msn.com",
+    "msndirect.com",
     "msocdn.com",
+    "netconversions.com",
+    "o365weve.com",
+    "oaspapps.com",
     "office365.com",
     "office.com",
+    "officelive.com",
     "office.net",
+    "olsvc.com",
     "onedrive.com",
     "onenote.com",
+    "onenote.net",
     "onestore.ms",
+    "onmicrosoft.com",
+    "outlook.com",
+    "outlookmobile.com",
     "passport.net",
+    "phonefactor.net",
+    "powerapps.com",
+    "roiservice.com",
+    "sfbassets.com",
+    "sfx.ms",
     "sharepoint.com",
     "sharepoint-df.com",
     "sharept.ms",
     "skypeassets.com",
     "skype.com",
+    "skypeforbusiness.com",
     "s-microsoft.com",
+    "s-msn.com",
+    "staffhub.ms",
     "svc.ms",
+    "sway-cdn.com",
+    "sway.com",
+    "sway-extensions.com",
+    "trafficmanager.net",
+    "virtualearth.net",
     "visualstudio.com",
     "vsallin.net",
     "vsassets.io",
     "windowsazure.com",
     "windows.com",
+    "windows.net",
+    "windowsphone.com",
+    "worldwidetelescope.org",
+    "wunderlist.com",
     "xbox.com",
     "xboxlive.com",
     "yammer.com",
+    "yammerusercontent.com",
   ],
   ["mobilism.org.in", "mobilism.org"],
   ["morganstanley.com", "morganstanleyclientserv.com", "stockplanconnect.com", "ms.com"],
+  [
+    "morningstar.com",
+
+    "morningstar.at",
+    "morningstar.be",
+    "morningstarbr.com",
+    "morningstar.ca",
+    "morningstar.ch",
+    "morningstar.cl",
+    "morningstar.co.il",
+    "morningstar.com.mx",
+    "morningstar.co.uk",
+    "morningstar.de",
+    "morningstar.dk",
+    "morningstar.es",
+    "morningstar.fi",
+    "morningstar.fr",
+    "morningstarfunds.ie",
+    "morningstar.it",
+    "morningstar.nl",
+    "morningstar.no",
+    "morningstar.pt",
+    "morningstar.se",
+    "morningstarthailand.com",
+  ],
   [
     "mtv.fi",
 
@@ -1232,6 +1998,19 @@ var multiDomainFirstPartiesArray = [
     "s-nbcnews.com",
   ],
   ["nefcuonline.com", "nefcu.com"],
+  [
+    "netease.com",
+
+    "126.com",
+    "126.net",
+    "127.net",
+    "163.com",
+
+    "icourse163.org",
+    "kada.com",
+    "kaola.com",
+    "kaola.com.hk",
+  ],
   ["netflix.com", "nflxext.com", "nflximg.net", "nflxvideo.net"],
   [
     "nettix.fi",
@@ -1455,6 +2234,28 @@ var multiDomainFirstPartiesArray = [
   ],
   ["paypal.com", "paypal-search.com"],
   ["pcworld.com", "staticworld.net", "idg.com", "idg.net", "infoworld.com", "macworld.com", "techhive.com", "idg.tv"],
+  [
+    "pearson.com",
+
+    "connexus.com",
+    "ecollege.com",
+    "english.com",
+    "masteringchemistry.com",
+    "masteringengineering.com",
+    "masteringgeography.com",
+    "masteringhealthandnutrition.com",
+    "masteringphysics.com",
+    "mathxl.com",
+    "mathxlforschool.com",
+    "mypearson.com",
+    "pearsonassessments.com",
+    "pearsoned.com",
+    "pearsonelt.com",
+    "pearsonhighered.com",
+    "pearsonmylabandmastering.com",
+
+    "pearsoncmg.com",
+  ],
   ["pepco.com", "pepcoholdings.com"],
   ["philips.com", "philips.nl"],
   [
@@ -1509,7 +2310,7 @@ var multiDomainFirstPartiesArray = [
     "pinimg.com",
     "pin.it",
   ],
-  ["playstation.com", "sonyentertainmentnetwork.com"],
+  ["plex.tv", "plex.direct"],
   ["pokemon-gl.com", "pokemon.com"],
   ["pornhub.com", "phncdn.com"],
   ["postepay.it", "poste.it"],
@@ -1587,6 +2388,34 @@ var multiDomainFirstPartiesArray = [
   ],
   ["reddit.com", "redditmedia.com", "redditstatic.com", "redd.it", "redditenhancementsuite.com", "reddituploads.com", "imgur.com"],
   ["redhat.com", "openshift.com", "openshift.org", "okd.io"],
+  [
+    "reebok.at",
+    "reebok.be",
+    "reebok.ca",
+    "reebok.ch",
+    "reebok.cl",
+    "reebok.co",
+    "reebok.com",
+    "reebok.com.ar",
+    "reebok.com.br",
+    "reebok.com.tr",
+    "reebok.co.uk",
+    "reebok.cz",
+    "reebok.de",
+    "reebok.dk",
+    "reebok.es",
+    "reebok.fi",
+    "reebok.fr",
+    "reebok.ie",
+    "reebok.it",
+    "reebok.mx",
+    "reebok.nl",
+    "reebok.pe",
+    "reebok.pl",
+    "reebok.ru",
+    "reebok.se",
+    "reebok.sk",
+  ],
   [
     "reuters.com",
     "reuters.tv",
@@ -1612,6 +2441,33 @@ var multiDomainFirstPartiesArray = [
     "thomsonreuters.in",
     "thomsonreuters.ru",
   ],
+  [
+    "riotgames.com",
+
+    "leagueoflegends.com",
+    "lolesports.com",
+    "lolstatic.com",
+    "lolusercontent.com",
+
+    "playruneterra.com",
+
+    "riotcdn.net",
+    "rdatasrv.net",
+  ],
+  [
+    "rtl.nl",
+
+    "bright.nl",
+    "buienradar.nl",
+    "healthyfest.nl",
+    "rtlboulevard.nl",
+    "rtllatenight.nl",
+    "rtlnieuws.nl",
+    "rtlxl.nl",
+    "rtlz.nl",
+    "videoland.com",
+    "vtbl.nl",
+  ],
   [
     "s-kanava.fi",
 
@@ -1627,15 +2483,51 @@ var multiDomainFirstPartiesArray = [
   [
     "salesforce.com",
 
+    "documentforce.com",
     "einstein.com",
     "force.com",
     "pardot.com",
     "salesforceliveagent.com",
+    "visualforce.com",
   ],
   ["sanguosha.com", "bianfeng.com"],
   ["schwab.com", "schwabplan.com"],
+  ["scmp.com", "i-scmp.com"],
   ["sears.com", "shld.net"],
-  ["shopify.com", "myshopify.com"],
+  [
+    "seznam.cz",
+
+    "firmy.cz",
+    "garaz.cz",
+    "kupi.cz",
+    "lide.cz",
+    "mapy.cz",
+    "novinky.cz",
+    "prozeny.cz",
+    "sauto.cz",
+    "sbazar.cz",
+    "sdovolena.cz",
+    "seznamzpravy.cz",
+    "sport.cz",
+    "sreality.cz",
+    "stream.cz",
+    "super.cz",
+    "sweb.cz",
+    "televizeseznam.cz",
+    "volnamista.cz",
+    "zbozi.cz",
+
+    "szn.cz",
+  ],
+  [
+    "shopify.com",
+    "myshopify.com",
+    "shopifycdn.com",
+    "shopifyapps.com",
+    "shopifycloud.com",
+    "shopifyadmin.com",
+    "shopifypreview.com",
+  ],
   ["siriusxm.com", "sirius.com"],
   ["skygo.co.nz", "skytv.co.nz"],
   ["skysports.com", "skybet.com", "skyvegas.com"],
@@ -1654,10 +2546,94 @@ var multiDomainFirstPartiesArray = [
     "ffx.io",
   ],
   ["snapfish.com", "snapfish.ca"],
-  ["sony.com", "sonyrewards.com"],
+  [
+    "sony.com",
+
+    "sonyentertainmentnetwork.com",
+    "sonyrewards.com",
+
+    "playstation.com",
+    "playstation.net",
+
+    "sony-africa.com",
+    "sony-asia.com",
+    "sony.at",
+    "sony.ba",
+    "sony.be",
+    "sony.bg",
+    "sony.ca",
+    "sony.ch",
+    "sony.cl",
+    "sony.co.cr",
+    "sony.co.id",
+    "sony.co.in",
+    "sony.co.kr",
+    "sony.com.ar",
+    "sony.com.au",
+    "sony.com.bo",
+    "sony.com.br",
+    "sony.com.co",
+    "sony.com.do",
+    "sony.com.ec",
+    "sony.com.gt",
+    "sony.com.hk",
+    "sony.com.hn",
+    "sony.com.mk",
+    "sony.com.mx",
+    "sony.com.my",
+    "sony.com.ni",
+    "sony.com.pa",
+    "sony.com.pe",
+    "sony.com.ph",
+    "sony.com.sg",
+    "sony.com.sv",
+    "sony.com.tr",
+    "sony.com.tw",
+    "sony.com.vn",
+    "sony.co.nz",
+    "sony.co.th",
+    "sony.co.uk",
+    "sony.cz",
+    "sony.de",
+    "sony.dk",
+    "sony.ee",
+    "sony.es",
+    "sony.eu",
+    "sony-europe.com",
+    "sony.fi",
+    "sony.fr",
+    "sony.gr",
+    "sony.hr",
+    "sony.hu",
+    "sony.ie",
+    "sony.it",
+    "sony.kz",
+    "sony-latin.com",
+    "sonylatvija.com",
+    "sony.lt",
+    "sony.lu",
+    "sony.lv",
+    "sony-mea.com",
+    "sony.nl",
+    "sony.no",
+    "sony.pl",
+    "sony-promotion.eu",
+    "sony.pt",
+    "sony.ro",
+    "sony.rs",
+    "sony.ru",
+    "sony.se",
+    "sony.si",
+    "sony.sk",
+    "sony.ua",
+
+    "sony.net",
+  ],
+  ["soundcloud.com", "sndcdn.com"],
   ["soundcu.com", "netteller.com"],
   ["southerncompany.com", "southernco.com"],
   ["southparkstudios.com", "cc.com", "comedycentral.com"],
+  ["spiceworks.com", "spiceworksstatic.com"],
   [
     "spotify.com",
 
@@ -1698,6 +2674,7 @@ var multiDomainFirstPartiesArray = [
   ["sprint.com", "sprintpcs.com", "nextel.com"],
   ["squareup.com", "cash.app", "mkt.com", "squarecdn.com"],
   ["steampowered.com", "steamstatic.com", "steamcommunity.com"],
+  ["suning.com", "suning.cn", "hksuning.com"],
   ["techdata.com", "techdata.ch"],
   ["telegram.org", "telegram.me", "t.me"],
   ["telekom.com", "t-online.de"],
@@ -1857,11 +2834,23 @@ var multiDomainFirstPartiesArray = [
   ],
   ["trsretire.com", "divinvest.com"],
   ["turbotax.com", "intuit.com"],
-  ["twitch.tv", "ttvnw.net", "jtvnw.net"],
+  [
+    "tvn.pl",
+
+    "player.pl",
+    "tvn24bis.pl",
+    "tvn24.pl",
+
+    "cdntvn.pl",
+  ],
+  ["tvp.pl", "tvp.info"],
   ["twitter.com", "twimg.com", "t.co"],
   ["ua2go.com", "ual.com", "united.com", "unitedwifi.com"],
   ["ubisoft.com", "ubi.com", "anno-union.com", "thesettlers-alliance.com"],
+  ["ui.com", "ubnt.com"],
+  ["vanguard.com", "investornews.vanguard", "vanguardblog.com", "vanguardcanada.ca", "vanguardinvestor.co.uk", "vgcontent.info"],
   ["verizon.com", "verizon.net", "verizonwireless.com", "vzw.com"],
+  ["vimeo.com", "vimeocdn.com"],
   [
     "vinted.com",
 
@@ -1879,7 +2868,190 @@ var multiDomainFirstPartiesArray = [
   ["vk.com", "vk.me", "vkontakte.ru"],
   ["volvooceanrace.com", "virtualregatta.com"],
   ["vonage.com", "vonagebusiness.com"],
+  [
+    "vrt.be",
+
+    "canvas.be",
+    "een.be",
+    "ketnet.be",
+    "klara.be",
+    "mnm.be",
+    "radio1.be",
+    "radio2.be",
+    "sporza.be",
+    "stubru.be",
+  ],
   ["walmart.com", "wal.co", "walmartimages.com", "walmart.ca"],
+  [
+    "thewaltdisneycompany.com",
+
+    "6abc.com",
+    "abc7.com",
+    "abc7ny.com",
+    "abc.com",
+    "abcnews.com",
+
+    "go.com",
+
+    "espn.com",
+    "espncdn.com",
+
+    "espn.com.au",
+    "espn.com.br",
+    "espn.co.uk",
+
+    "espncricinfo.com",
+
+    "espnfc.com",
+    "espnfc.us",
+
+    "fivethirtyeight.com",
+
+    "babble.com",
+    "dadt.com",
+    "disneybaby.com",
+    "disneyinteractive.com",
+    "disneyinternationalhd.com",
+    "disneymoviesanywhere.com",
+    "ilm.com",
+    "marvel.com",
+    "readriordan.com",
+    "skysound.com",
+    "starwars.com",
+
+    "disney.asia",
+    "disney.be",
+    "disney.bg",
+    "disney.co.il",
+    "disney.com",
+    "disney.com.au",
+    "disney.com.br",
+    "disney.com.hk",
+    "disney.com.tw",
+    "disney.co.th",
+    "disney.co.uk",
+    "disney.co.za",
+    "disney.cz",
+    "disney.de",
+    "disney.dk",
+    "disney.es",
+    "disney.fi",
+    "disney.fr",
+    "disney.gr",
+    "disney.hu",
+    "disney.id",
+    "disney.in",
+    "disney.it",
+    "disneylatino.com",
+    "disneyme.com",
+    "disney.my",
+    "disney.nl",
+    "disney.no",
+    "disney.ph",
+    "disney.pl",
+    "disney.pt",
+    "disney.ro",
+    "disney.se",
+    "disney.sg",
+    "disneyturkiye.com.tr",
+
+    "dilcdn.com",
+    "disney.io",
+  ],
+  [
+    "wargaming.com",
+    "wargaming.net",
+    "worldoftanks.asia",
+    "worldoftanks.com",
+    "worldoftanks.eu",
+    "worldoftanks.kr",
+    "worldoftanks.ru",
+    "worldofwarplanes.com",
+    "worldofwarplanes.eu",
+    "worldofwarplanes.ru",
+    "worldofwarships.com",
+    "worldofwarships.eu",
+    "worldofwarships.ru",
+    "wotblitz.com",
+  ],
+  [
+    "warnermediagroup.com",
+
+    "adultswim.com",
+    "adventuretime.com",
+    "atgamewiz.com",
+    "ben10.com",
+    "bleacherreport.com",
+    "bleacherreportlive.com",
+    "br.live",
+    "brlive.com",
+    "brlive.io",
+    "cartoonnetwork.asia",
+    "cartoonnetworkasia.com",
+    "cartoonnetwork.com",
+    "cartoonnetworkhotel.com",
+    "cartoonnetworkpr.com",
+    "catchsports.com",
+    "chasingthecurelive.com",
+    "cnn.com",
+    "cnn.io",
+    "cnnmoney.ch",
+    "cnn.net",
+    "d2c-ott.com",
+    "d-league.com",
+    "e-league.com",
+    "eleague.com",
+    "filmstruck.com",
+    "greatbig.com",
+    "greatbigstory.com",
+    "heaveninc.com",
+    "hlntv.com",
+    "iamthenight.com",
+    "juniorrydercup.com",
+    "nba.com",
+    "nba.net",
+    "ncaa.com",
+    "ngtv.io",
+    "penis-map.com",
+    "pgachampionship.com",
+    "pga.com",
+    "pga-events.com",
+    "pga.net",
+    "powerpuffgirls.com",
+    "powerpufftheworld.com",
+    "robotunicornattack.com",
+    "rydercup.com",
+    "samanthabee.com",
+    "sambee.com",
+    "shaqtoons.com",
+    "stevenuniverseselfesteem.com",
+    "stevenuniversethemovie.com",
+    "summercampisland.com",
+    "superstation.com",
+    "suspensecollection.com",
+    "tbs.com",
+    "tcm.com",
+    "teamcococdn.com",
+    "thealienist.com",
+    "thesuspensecollection.com",
+    "ti-platform.com",
+    "tntdrama.com",
+    "tnt.tv",
+    "trutv.com",
+    "vgtf.net",
+    "warnermediacdn.com",
+    "warnermediafitnation.com",
+    "warnermediaready.com",
+    "warnermediasupplierdiversity.com",
+    "warnermediaupfront.com",
+    "wbtvd.com",
+    "webarebears.com",
+    "wnba.com",
+    "yzzerdd.com",
+
+    "turner.com",
+    "ugdturner.com",
+  ],
   [
     "webmd.com",
 
@@ -1935,12 +3107,14 @@ var multiDomainFirstPartiesArray = [
   ["wsj.com", "wsj.net", "barrons.com", "dowjones.com", "marketwatch.com"],
   ["xda-developers.com", "xda-cdn.com"],
   ["xfinity.com", "comcast.net", "comcast.com"],
+  ["xhamster.com", "xhcdn.com"],
   ["yahoo.com", "yahooapis.com", "yimg.com", "yahoo.co.jp", "overture.com", "flickr.com"],
   [
     "yandex.com",
 
     "auto.ru",
     "beru.ru",
+    "bringly.ru",
     "kinopoisk.ru",
     "mykp.ru",
     "yadi.sk",
@@ -1970,7 +3144,7 @@ var multiDomainFirstPartiesArray = [
     "ya.ru",
   ],
   ["zendesk.com", "zopim.com"],
-  ["zillow.com", "zillowstatic.com", "zillowcloud.com"],
+  ["zillow.com", "zillowstatic.com", "zillowcloud.com", "zg-api.com"],
   ["zoho.com", "zoho.eu", "zohocorp.com", "zohocreator.com", "zohopublic.com", "zohostatic.com"],
   ["zonealarm.com", "zonelabs.com"],
 ];
