@@ -438,11 +438,10 @@ function refreshPopup() {
   window.SLIDERS_DONE = false;
 
   // must be a special browser page,
-  // or a page that loaded everything before our most recent initialization
   if (POPUP_DATA.noTabData) {
-    // replace inapplicable summary text with a Badger logo
+    // show the "nothing to do here" message
     $('#blockedResourcesContainer').hide();
-    $('#big-badger-logo').show();
+    $('#special-browser-page').show();
 
     // hide inapplicable buttons
     $('#deactivate_site_btn').hide();
@@ -459,7 +458,7 @@ function refreshPopup() {
   // revert any hiding/showing above for cases when refreshPopup gets called
   // more than once for the same popup, such as during functional testing
   $('#blockedResourcesContainer').show();
-  $('#big-badger-logo').hide();
+  $('#special-browser-page').hide();
   $('#deactivate_site_btn').show();
   $('#error').show();
 
@@ -468,6 +467,7 @@ function refreshPopup() {
     $("#blockedResourcesContainer").hide();
     $("#activate_site_btn").show();
     $("#deactivate_site_btn").hide();
+    $("#disabled-site-message").show();
   }
 
   // if there is any saved error text, fill the error input with it
@@ -491,7 +491,7 @@ function refreshPopup() {
 
     if (POPUP_DATA.showNonTrackingDomains) {
       // show the "no third party resources on this site" message
-      $("#blockedResources").html(chrome.i18n.getMessage("popup_blocked"));
+      $("#no-third-parties").show();
     }
 
     // activate tooltips
@@ -502,27 +502,44 @@ function refreshPopup() {
     return;
   }
 
-  var printable = [];
-  var nonTracking = [];
+  let printable = [];
+  let unblockedTrackers = [];
+  let nonTracking = [];
   originsArr = htmlUtils.sortDomains(originsArr);
 
   for (let i=0; i < originsArr.length; i++) {
-    var origin = originsArr[i];
-    var action = origins[origin];
+    let origin = originsArr[i];
+    let action = origins[origin];
 
     if (action == constants.NO_TRACKING) {
       nonTracking.push(origin);
-      continue;
+    } else if (action == constants.ALLOW) {
+      unblockedTrackers.push(origin);
+    } else {
+      printable.push(
+        htmlUtils.getOriginHtml(origin, action, action == constants.DNT)
+      );
     }
-
-    printable.push(
-      htmlUtils.getOriginHtml(origin, action, action == constants.DNT)
-    );
   }
 
-  if (POPUP_DATA.showNonTrackingDomains && nonTracking.length > 0) {
+  if (unblockedTrackers.length) {
     printable.push(
-      '<div class="clicker tooltip" id="nonTrackers" title="' +
+      '<div class="clicker tooltip" id="not-yet-blocked-header" title="' +
+      chrome.i18n.getMessage("intro_not_an_adblocker_paragraph") +
+      '" data-tooltipster=\'{"side":"top"}\'>' +
+      chrome.i18n.getMessage("not_yet_blocked_header") +
+      '</div>'
+    );
+    unblockedTrackers.forEach(domain => {
+      printable.push(
+        htmlUtils.getOriginHtml(domain, constants.ALLOW, false)
+      );
+    });
+  }
+
+  if (POPUP_DATA.showNonTrackingDomains && nonTracking.length) {
+    printable.push(
+      '<div class="clicker tooltip" id="non-trackers-header" title="' +
       chrome.i18n.getMessage("non_tracker_tip") +
       '" data-tooltipster=\'{"side":"top"}\'>' +
       chrome.i18n.getMessage("non_tracker") +
@@ -533,6 +550,9 @@ function refreshPopup() {
         htmlUtils.getOriginHtml(nonTracking[i], constants.NO_TRACKING, false)
       );
     }
+
+    // reduce margin if we have non-tracking domains to show
+    $("#instructions_no_trackers").css("margin", "10px 0");
   }
 
   if (printable.length) {
