@@ -31,7 +31,6 @@ require.scopes.webrequest = (function() {
 var constants = require("constants");
 var getSurrogateURI = require("surrogates").getSurrogateURI;
 var incognito = require("incognito");
-var mdfp = require("multiDomainFP");
 var utils = require("utils");
 
 /************ Local Variables *****************/
@@ -53,9 +52,7 @@ function onBeforeRequest(details) {
 
   if (type == "main_frame") {
     forgetTab(tab_id);
-
     badger.recordFrame(tab_id, frame_id, url);
-
     return {};
   }
 
@@ -74,14 +71,14 @@ function onBeforeRequest(details) {
     return {};
   }
 
-  var tabDomain = getHostForTab(tab_id);
-  var requestDomain = window.extractHostFromURL(url);
+  let tab_host = getHostForTab(tab_id);
+  let request_host = window.extractHostFromURL(url);
 
-  if (!isThirdPartyDomain(requestDomain, tabDomain)) {
+  if (!utils.isThirdPartyDomain(request_host, tab_host)) {
     return {};
   }
 
-  var requestAction = checkAction(tab_id, requestDomain, frame_id);
+  var requestAction = checkAction(tab_id, request_host, frame_id);
   if (!requestAction) {
     return {};
   }
@@ -89,10 +86,10 @@ function onBeforeRequest(details) {
   // log the third-party domain asynchronously
   // (don't block a critical code path on updating the badge)
   setTimeout(function () {
-    badger.logThirdPartyOriginOnTab(tab_id, requestDomain, requestAction);
+    badger.logThirdPartyOriginOnTab(tab_id, request_host, requestAction);
   }, 0);
 
-  if (!badger.isPrivacyBadgerEnabled(tabDomain)) {
+  if (!badger.isPrivacyBadgerEnabled(tab_host)) {
     return {};
   }
 
@@ -101,7 +98,7 @@ function onBeforeRequest(details) {
   }
 
   if (type == 'script') {
-    var surrogate = getSurrogateURI(url, requestDomain);
+    var surrogate = getSurrogateURI(url, request_host);
     if (surrogate) {
       return {redirectUrl: surrogate};
     }
@@ -110,7 +107,7 @@ function onBeforeRequest(details) {
   // Notify the content script...
   var msg = {
     replaceWidget: true,
-    trackerDomain: requestDomain
+    trackerDomain: request_host
   };
   chrome.tabs.sendMessage(tab_id, msg);
 
@@ -118,7 +115,7 @@ function onBeforeRequest(details) {
   if (requestAction == constants.BLOCK && incognito.learningEnabled(tab_id)) {
     // check for DNT policy asynchronously
     setTimeout(function () {
-      badger.checkForDNTPolicy(requestDomain);
+      badger.checkForDNTPolicy(request_host);
     }, 0);
   }
 
@@ -163,11 +160,11 @@ function onBeforeSendHeaders(details) {
     return {};
   }
 
-  var tabDomain = getHostForTab(tab_id);
-  var requestDomain = window.extractHostFromURL(url);
+  let tab_host = getHostForTab(tab_id);
+  let request_host = window.extractHostFromURL(url);
 
-  if (!isThirdPartyDomain(requestDomain, tabDomain)) {
-    if (badger.isPrivacyBadgerEnabled(tabDomain)) {
+  if (!utils.isThirdPartyDomain(request_host, tab_host)) {
+    if (badger.isPrivacyBadgerEnabled(tab_host)) {
       // Still sending Do Not Track even if HTTP and cookie blocking are disabled
       if (badger.isDNTSignalEnabled()) {
         details.requestHeaders.push({name: "DNT", value: "1"});
@@ -178,73 +175,53 @@ function onBeforeSendHeaders(details) {
     }
   }
 
-  var requestAction = checkAction(tab_id, requestDomain, frame_id);
+  var requestAction = checkAction(tab_id, request_host, frame_id);
 
   if (requestAction) {
     // log the third-party domain asynchronously
     setTimeout(function () {
-      badger.logThirdPartyOriginOnTab(tab_id, requestDomain, requestAction);
+      badger.logThirdPartyOriginOnTab(tab_id, request_host, requestAction);
     }, 0);
   }
 
-  // If this might be the third strike against the potential tracker which
-  // would cause it to be blocked we should check immediately if it will be blocked.
-  if (requestAction == constants.ALLOW &&
-      badger.storage.getTrackingCount(requestDomain) == constants.TRACKING_THRESHOLD - 1) {
-
-    badger.heuristicBlocking.heuristicBlockingAccounting(details, false);
-    requestAction = checkAction(tab_id, requestDomain, frame_id);
-
-    if (requestAction) {
-      // log the third-party domain asynchronously
-      setTimeout(function () {
-        badger.logThirdPartyOriginOnTab(tab_id, requestDomain, requestAction);
-      }, 0);
-    }
-  }
-
-  if (!badger.isPrivacyBadgerEnabled(tabDomain)) {
+  if (!badger.isPrivacyBadgerEnabled(tab_host)) {
     return {};
   }
 
-  // This will only happen if the above code sets the action for the request
-  // to block
-  if (requestAction == constants.BLOCK) {
-    if (type == 'script') {
-      var surrogate = getSurrogateURI(url, requestDomain);
-      if (surrogate) {
-        return {redirectUrl: surrogate};
-      }
-    }
-
-    // Notify the content script...
-    var msg = {
-      replaceWidget: true,
-      trackerDomain: requestDomain
-    };
-    chrome.tabs.sendMessage(tab_id, msg);
-
-    if (type == 'sub_frame' && badger.getSettings().getItem('hideBlockedElements')) {
-      return {
-        redirectUrl: 'about:blank'
-      };
-    }
-
-    return {cancel: true};
-  }
-
-  // This is the typical codepath
+  // handle cookieblocked requests
   if (requestAction == constants.COOKIEBLOCK || requestAction == constants.USER_COOKIE_BLOCK) {
-    let newHeaders = details.requestHeaders.filter(function (header) {
-      return (header.name.toLowerCase() != "cookie" && header.name.toLowerCase() != "referer");
-    });
+    let newHeaders;
+
+    // GET requests: remove cookie headers, reduce referrer header to origin
+    if (details.method == "GET") {
+      newHeaders = details.requestHeaders.filter(header => {
+        return (header.name.toLowerCase() != "cookie");
+      }).map(header => {
+        if (header.name.toLowerCase() == "referer") {
+          header.value = header.value.slice(
+            0,
+            header.value.indexOf('/', header.value.indexOf('://') + 3)
+          ) + '/';
+        }
+        return header;
+      });
+
+    // remove cookie and referrer headers otherwise
+    } else {
+      newHeaders = details.requestHeaders.filter(header => {
+        return (header.name.toLowerCase() != "cookie" && header.name.toLowerCase() != "referer");
+      });
+    }
+
+    // add DNT header
     if (badger.isDNTSignalEnabled()) {
       newHeaders.push({name: "DNT", value: "1"});
     }
+
     return {requestHeaders: newHeaders};
   }
 
-  // if we are here, we're looking at a third party
+  // if we are here, we're looking at a third-party request
   // that's not yet blocked or cookieblocked
   if (badger.isDNTSignalEnabled()) {
     details.requestHeaders.push({name: "DNT", value: "1"});
@@ -288,24 +265,24 @@ function onHeadersReceived(details) {
     return {};
   }
 
-  var tabDomain = getHostForTab(tab_id);
-  var requestDomain = window.extractHostFromURL(url);
+  let tab_host = getHostForTab(tab_id);
+  let request_host = window.extractHostFromURL(url);
 
-  if (!isThirdPartyDomain(requestDomain, tabDomain)) {
+  if (!utils.isThirdPartyDomain(request_host, tab_host)) {
     return {};
   }
 
-  var requestAction = checkAction(tab_id, requestDomain, details.frameId);
+  var requestAction = checkAction(tab_id, request_host, details.frameId);
   if (!requestAction) {
     return {};
   }
 
   // log the third-party domain asynchronously
   setTimeout(function () {
-    badger.logThirdPartyOriginOnTab(tab_id, requestDomain, requestAction);
+    badger.logThirdPartyOriginOnTab(tab_id, request_host, requestAction);
   }, 0);
 
-  if (!badger.isPrivacyBadgerEnabled(tabDomain)) {
+  if (!badger.isPrivacyBadgerEnabled(tab_host)) {
     return {};
   }
 
@@ -340,25 +317,42 @@ function onTabReplaced(addedTabId, removedTabId) {
   badger.updateBadge(addedTabId);
 }
 
-/******** Utility Functions **********/
-
 /**
- * check if a domain is third party
- * @param {String} domain1 an fqdn
- * @param {String} domain2 a second fqdn
- *
- * @return {Boolean} true if the domains are third party
+ * We don't always get a "main_frame" details object in onBeforeRequest,
+ * so we need a fallback for (re)initializing tabData.
  */
-function isThirdPartyDomain(domain1, domain2) {
-  if (window.isThirdParty(domain1, domain2)) {
-    return !mdfp.isMultiDomainFirstParty(
-      window.getBaseDomain(domain1),
-      window.getBaseDomain(domain2)
-    );
+function onNavigate(details) {
+  const tab_id = details.tabId,
+    url = details.url;
+
+  // main (top-level) frames only
+  if (details.frameId !== 0) {
+    return;
   }
-  return false;
+
+  // forget but don't initialize on special browser/extension pages
+  if (utils.isRestrictedUrl(url)) {
+    forgetTab(tab_id);
+    return;
+  }
+
+  forgetTab(tab_id);
+  badger.recordFrame(tab_id, 0, url);
+
+  // initialize tab data bookkeeping used by heuristicBlockingAccounting()
+  // to avoid missing or misattributing learning
+  // when there is no "main_frame" webRequest callback
+  // (such as on Service Worker pages)
+  //
+  // see the tabOrigins TODO in heuristicblocking.js
+  // as to why we don't just use tabData
+  let base = window.getBaseDomain(badger.tabData[tab_id].frames[0].host);
+  badger.heuristicBlocking.tabOrigins[tab_id] = base;
+  badger.heuristicBlocking.tabUrls[tab_id] = url;
 }
 
+/******** Utility Functions **********/
+
 /**
  * Gets the host name for a given tab id
  * @param {Integer} tabId chrome tab id
@@ -397,7 +391,7 @@ function recordSuperCookie(tab_id, frame_url) {
   const frame_host = window.extractHostFromURL(frame_url),
     page_host = badger.getFrameData(tab_id).host;
 
-  if (!isThirdPartyDomain(frame_host, page_host)) {
+  if (!utils.isThirdPartyDomain(frame_host, page_host)) {
     // Only happens on the start page for google.com
     return;
   }
@@ -425,7 +419,7 @@ function recordFingerprinting(tabId, msg) {
   // Ignore first-party scripts
   var script_host = window.extractHostFromURL(msg.scriptUrl),
     document_host = badger.getFrameData(tabId).host;
-  if (!isThirdPartyDomain(script_host, document_host)) {
+  if (!utils.isThirdPartyDomain(script_host, document_host)) {
     return;
   }
 
@@ -583,9 +577,14 @@ let getWidgetBlockList = (function () {
     }
 
     badger.widgetList.forEach(function (widget) {
-      // Only replace blocked and yellowlisted widgets
-      widgetsToReplace[widget.name] = constants.BLOCKED_ACTIONS.has(
-        badger.storage.getBestAction(widget.domain)
+      // replace blocked widgets only
+      // and only if the widget is not on the 'do not replace' list
+      const replace = !badger.getSettings().getItem('widgetReplacementExceptions').includes(widget.name);
+      const action = badger.storage.getBestAction(widget.domain);
+
+      widgetsToReplace[widget.name] = replace && (
+        action == constants.BLOCK ||
+        action == constants.USER_BLOCK
       );
     });
 
@@ -632,6 +631,7 @@ function unblockWidgetOnTab(tabId, widgetUrls) {
   }
   for (let i in widgetUrls) {
     let url = widgetUrls[i];
+    // TODO just store actual domains in the JSON in the first place
     let host = window.extractHostFromURL(url);
     temporaryWidgetUnblock[tabId].push(host);
   }
@@ -639,12 +639,40 @@ function unblockWidgetOnTab(tabId, widgetUrls) {
 
 // NOTE: sender.tab is available for content script (not popup) messages only
 function dispatcher(request, sender, sendResponse) {
-  if (request.checkEnabled) {
+
+  // messages from content scripts are to be treated with greater caution:
+  // https://groups.google.com/a/chromium.org/d/msg/chromium-extensions/0ei-UCHNm34/lDaXwQhzBAAJ
+  if (!sender.url.startsWith(chrome.runtime.getURL(""))) {
+    // reject unless it's a known content script message
+    const KNOWN_CONTENT_SCRIPT_MESSAGES = [
+      "checkDNT",
+      "checkEnabled",
+      "checkEnabledAndThirdParty",
+      "checkLocation",
+      "checkReplaceButton",
+      "checkWidgetReplacementEnabled",
+      "fpReport",
+      "getReplacementButton",
+      "supercookieReport",
+      "unblockWidget",
+    ];
+    if (!KNOWN_CONTENT_SCRIPT_MESSAGES.includes(request.type)) {
+      console.error("Rejected unknown message %o from %s", request, sender.url);
+      return sendResponse();
+    }
+  }
+
+  switch (request.type) {
+
+  case "checkEnabled": {
     sendResponse(badger.isPrivacyBadgerEnabled(
       window.extractHostFromURL(sender.tab.url)
     ));
 
-  } else if (request.checkLocation) {
+    break;
+  }
+
+  case "checkLocation": {
     if (!badger.isPrivacyBadgerEnabled(window.extractHostFromURL(sender.tab.url))) {
       return sendResponse();
     }
@@ -654,31 +682,53 @@ function dispatcher(request, sender, sendResponse) {
       return sendResponse();
     }
 
-    let requestHost = window.extractHostFromURL(request.checkLocation);
+    let frame_host = window.extractHostFromURL(request.frameUrl),
+      tab_host = window.extractHostFromURL(sender.tab.url);
 
     // Ignore requests that aren't from a third party.
-    if (!isThirdPartyDomain(requestHost, window.extractHostFromURL(sender.tab.url))) {
+    if (!frame_host || !utils.isThirdPartyDomain(frame_host, tab_host)) {
       return sendResponse();
     }
 
-    var reqAction = checkAction(sender.tab.id, requestHost);
-    var cookieBlock = reqAction == constants.COOKIEBLOCK || reqAction == constants.USER_COOKIE_BLOCK;
-    sendResponse(cookieBlock);
+    let action = checkAction(sender.tab.id, frame_host);
+    sendResponse(action == constants.COOKIEBLOCK || action == constants.USER_COOKIE_BLOCK);
 
-  } else if (request.checkReplaceButton) {
+    break;
+  }
+
+  case "checkReplaceButton": {
     if (badger.isPrivacyBadgerEnabled(window.extractHostFromURL(sender.tab.url)) && badger.isWidgetReplacementEnabled()) {
       let widgetBlockList = getWidgetBlockList();
       sendResponse(widgetBlockList);
     }
 
-  } else if (request.unblockWidget) {
-    unblockWidgetOnTab(sender.tab.id, request.buttonUrls);
-    sendResponse();
+    break;
+  }
 
-  } else if (request.getReplacementButton) {
+  case "unblockWidget": {
+    let widgetData = badger.widgetList.find(
+      widget => widget.name == request.widgetName);
+    if (!widgetData ||
+        !widgetData.hasOwnProperty("replacementButton") ||
+        !widgetData.replacementButton.unblockDomains) {
+      return sendResponse();
+    }
+    unblockWidgetOnTab(sender.tab.id, widgetData.replacementButton.unblockDomains);
+    sendResponse();
+    break;
+  }
+
+  case "getReplacementButton": {
+    let widgetData = badger.widgetList.find(
+      widget => widget.name == request.widgetName);
+    if (!widgetData ||
+        !widgetData.hasOwnProperty("replacementButton") ||
+        !widgetData.replacementButton.imagePath) {
+      return sendResponse();
+    }
 
     let button_path = chrome.runtime.getURL(
-      "skin/socialwidgets/" + request.getReplacementButton);
+      "skin/socialwidgets/" + widgetData.replacementButton.imagePath);
 
     let image_type = button_path.slice(button_path.lastIndexOf('.') + 1);
 
@@ -703,56 +753,81 @@ function dispatcher(request, sender, sendResponse) {
 
     // indicate this is an async response to chrome.runtime.onMessage
     return true;
+  }
 
-  // Canvas fingerprinting
-  } else if (request.fpReport) {
-    if (!badger.isPrivacyBadgerEnabled(window.extractHostFromURL(sender.tab.url))) { return; }
-    if (Array.isArray(request.fpReport)) {
-      request.fpReport.forEach(function (msg) {
+  case "fpReport": {
+    if (!badger.isPrivacyBadgerEnabled(window.extractHostFromURL(sender.tab.url))) {
+      return sendResponse();
+    }
+    if (Array.isArray(request.data)) {
+      request.data.forEach(function (msg) {
         recordFingerprinting(sender.tab.id, msg);
       });
     } else {
-      recordFingerprinting(sender.tab.id, request.fpReport);
+      recordFingerprinting(sender.tab.id, request.data);
     }
 
-  } else if (request.superCookieReport) {
-    if (badger.hasSuperCookie(request.superCookieReport)) {
+    break;
+  }
+
+  case "supercookieReport": {
+    if (request.frameUrl && badger.hasSuperCookie(request.data)) {
       recordSuperCookie(sender.tab.id, request.frameUrl);
     }
+    break;
+  }
 
-  } else if (request.checkEnabledAndThirdParty) {
+  case "checkEnabledAndThirdParty": {
     let tab_host = window.extractHostFromURL(sender.tab.url),
-      frame_host = window.extractHostFromURL(request.checkEnabledAndThirdParty);
+      frame_host = window.extractHostFromURL(request.frameUrl);
 
-    sendResponse(badger.isPrivacyBadgerEnabled(tab_host) && isThirdPartyDomain(frame_host, tab_host));
+    sendResponse(frame_host &&
+      badger.isPrivacyBadgerEnabled(tab_host) &&
+      utils.isThirdPartyDomain(frame_host, tab_host));
 
-  } else if (request.checkWidgetReplacementEnabled) {
+    break;
+  }
+
+  case "checkWidgetReplacementEnabled": {
     sendResponse(
       badger.isPrivacyBadgerEnabled(window.extractHostFromURL(sender.tab.url)) &&
       badger.isWidgetReplacementEnabled()
     );
+    break;
+  }
 
-  } else if (request.type == "getPopupData") {
-    let tab_id = request.tabId,
-      tab_url = request.tabUrl,
-      tab_host = window.extractHostFromURL(tab_url),
-      has_tab_data = badger.tabData.hasOwnProperty(tab_id);
+  case "getPopupData": {
+    let tab_id = request.tabId;
+
+    if (!badger.tabData.hasOwnProperty(tab_id)) {
+      sendResponse({
+        criticalError: badger.criticalError,
+        noTabData: true,
+        seenComic: true,
+      });
+      break;
+    }
+
+    let tab_host = window.extractHostFromURL(request.tabUrl);
 
     sendResponse({
       criticalError: badger.criticalError,
       enabled: badger.isPrivacyBadgerEnabled(tab_host),
-      errorText: has_tab_data && badger.tabData[tab_id].errorText,
-      noTabData: !has_tab_data,
-      origins: has_tab_data && badger.tabData[tab_id].origins,
+      errorText: badger.tabData[tab_id].errorText,
+      noTabData: false,
+      origins: badger.tabData[tab_id].origins,
       seenComic: badger.getSettings().getItem("seenComic"),
       showNonTrackingDomains: badger.getSettings().getItem("showNonTrackingDomains"),
       tabHost: tab_host,
       tabId: tab_id,
-      tabUrl: tab_url,
-      trackerCount: has_tab_data && badger.getTrackerCount(tab_id)
+      tabUrl: request.tabUrl,
+      trackerCount: badger.getTrackerCount(tab_id)
     });
 
-  } else if (request.type == "getOptionsData") {
+    break;
+  }
+
+  case "getOptionsData": {
     sendResponse({
       disabledSites: badger.getDisabledSites(),
       isCheckingDNTPolicyEnabled: badger.isCheckingDNTPolicyEnabled(),
@@ -764,37 +839,54 @@ function dispatcher(request, sender, sendResponse) {
       showNonTrackingDomains: badger.getSettings().getItem("showNonTrackingDomains"),
       showTrackingDomains: badger.getSettings().getItem("showTrackingDomains"),
       webRTCAvailable: badger.webRTCAvailable,
+      widgetReplacementExceptions: badger.getSettings().getItem("widgetReplacementExceptions"),
+      widgets: badger.widgetList.map(widget => widget.name),
     });
 
-  } else if (request.type == "resetData") {
+    break;
+  }
+
+  case "resetData": {
     badger.storage.clearTrackerData();
     badger.loadSeedData();
     sendResponse();
+    break;
+  }
 
-  } else if (request.type == "removeAllData") {
+  case "removeAllData": {
     badger.storage.clearTrackerData();
     sendResponse();
+    break;
+  }
 
-  } else if (request.type == "seenComic") {
+  case "seenComic": {
     badger.getSettings().setItem("seenComic", true);
+    break;
+  }
 
-  } else if (request.type == "activateOnSite") {
+  case "activateOnSite": {
     badger.enablePrivacyBadgerForOrigin(request.tabHost);
     badger.refreshIconAndContextMenu(request.tabId, request.tabUrl);
     sendResponse();
+    break;
+  }
 
-  } else if (request.type == "deactivateOnSite") {
+  case "deactivateOnSite": {
     badger.disablePrivacyBadgerForOrigin(request.tabHost);
     badger.refreshIconAndContextMenu(request.tabId, request.tabUrl);
     sendResponse();
+    break;
+  }
 
-  } else if (request.type == "revertDomainControl") {
+  case "revertDomainControl": {
     badger.storage.revertUserAction(request.origin);
     sendResponse({
       origins: badger.storage.getTrackingDomains()
     });
+    break;
+  }
 
-  } else if (request.type == "downloadCloud") {
+  case "downloadCloud": {
     chrome.storage.sync.get("disabledSites", function (store) {
       if (chrome.runtime.lastError) {
         sendResponse({success: false, message: chrome.runtime.lastError.message});
@@ -815,10 +907,12 @@ function dispatcher(request, sender, sendResponse) {
         });
       }
     });
-    //indicate this is an async response to chrome.runtime.onMessage
-    return true;
 
-  } else if (request.type == "uploadCloud") {
+    // indicate this is an async response to chrome.runtime.onMessage
+    return true;
+  }
+
+  case "uploadCloud": {
     let obj = {};
     obj.disabledSites = badger.getDisabledSites();
     chrome.storage.sync.set(obj, function () {
@@ -828,10 +922,11 @@ function dispatcher(request, sender, sendResponse) {
         sendResponse({success: true});
       }
     });
-    //indicate this is an async response to chrome.runtime.onMessage
+    // indicate this is an async response to chrome.runtime.onMessage
     return true;
+  }
 
-  } else if (request.type == "savePopupToggle") {
+  case "savePopupToggle": {
     let domain = request.origin,
       action = request.action;
 
@@ -840,22 +935,29 @@ function dispatcher(request, sender, sendResponse) {
     // update cached tab data so that a reopened popup displays correct state
     badger.tabData[request.tabId].origins[domain] = "user_" + action;
 
-  } else if (request.type == "saveOptionsToggle") {
+    break;
+  }
+
+  case "saveOptionsToggle": {
     // called when the user manually sets a slider on the options page
     badger.saveAction(request.action, request.origin);
     sendResponse({
       origins: badger.storage.getTrackingDomains()
     });
+    break;
+  }
 
-  } else if (request.type == "mergeUserData") {
+  case "mergeUserData": {
     // called when a user uploads data exported from another Badger instance
     badger.mergeUserData(request.data);
     sendResponse({
       disabledSites: badger.getDisabledSites(),
       origins: badger.storage.getTrackingDomains(),
     });
+    break;
+  }
 
-  } else if (request.type == "updateSettings") {
+  case "updateSettings": {
     const settings = badger.getSettings();
     for (let key in request.data) {
       if (badger.defaultSettings.hasOwnProperty(key)) {
@@ -865,42 +967,56 @@ function dispatcher(request, sender, sendResponse) {
       }
     }
     sendResponse();
+    break;
+  }
 
-  } else if (request.type == "updateBadge") {
+  case "updateBadge": {
     let tab_id = request.tab_id;
     badger.updateBadge(tab_id);
     sendResponse();
+    break;
+  }
 
-  } else if (request.type == "disablePrivacyBadgerForOrigin") {
+  case "disablePrivacyBadgerForOrigin": {
     badger.disablePrivacyBadgerForOrigin(request.domain);
     sendResponse({
       disabledSites: badger.getDisabledSites()
     });
+    break;
+  }
 
-  } else if (request.type == "enablePrivacyBadgerForOriginList") {
+  case "enablePrivacyBadgerForOriginList": {
     request.domains.forEach(function (domain) {
       badger.enablePrivacyBadgerForOrigin(domain);
     });
     sendResponse({
       disabledSites: badger.getDisabledSites()
     });
+    break;
+  }
 
-  } else if (request.type == "removeOrigin") {
+  case "removeOrigin": {
     badger.storage.getBadgerStorageObject("snitch_map").deleteItem(request.origin);
     badger.storage.getBadgerStorageObject("action_map").deleteItem(request.origin);
     sendResponse({
       origins: badger.storage.getTrackingDomains()
     });
+    break;
+  }
 
-  } else if (request.type == "saveErrorText") {
+  case "saveErrorText": {
     let activeTab = badger.tabData[request.tabId];
     activeTab.errorText = request.errorText;
+    break;
+  }
 
-  } else if (request.type == "removeErrorText") {
+  case "removeErrorText": {
     let activeTab = badger.tabData[request.tabId];
     delete activeTab.errorText;
+    break;
+  }
 
-  } else if (request.checkDNT) {
+  case "checkDNT": {
     // called from contentscripts/dnt.js to check if we should enable it
     sendResponse(
       badger.isDNTSignalEnabled()
@@ -908,11 +1024,16 @@ function dispatcher(request, sender, sendResponse) {
         window.extractHostFromURL(sender.tab.url)
       )
     );
+    break;
+  }
+
   }
 }
 
 /*************** Event Listeners *********************/
 function startListeners() {
+  chrome.webNavigation.onBeforeNavigate.addListener(onNavigate);
+
   chrome.webRequest.onBeforeRequest.addListener(onBeforeRequest, {urls: ["http://*/*", "https://*/*"]}, ["blocking"]);
 
   let extraInfoSpec = ['requestHeaders', 'blocking'];
