@@ -296,6 +296,25 @@ QUnit.test("cookie parsing", function (assert) {
     "duplicate names #3"
   );
 
+  // SameSite attribute
+  let SAMESITE_COOKIE = 'abc=123; path=/; domain=.githack.com; HttpOnly; SameSite=Lax';
+  assert.deepEqual(
+    utils.parseCookie(SAMESITE_COOKIE),
+    {
+      abc: '123',
+      SameSite: 'Lax',
+      path: '/',
+      domain: '.githack.com',
+      HttpOnly: '',
+    },
+    "SameSite is parsed"
+  );
+  assert.deepEqual(
+    utils.parseCookie(SAMESITE_COOKIE, { skipAttributes: true }),
+    { abc: '123' },
+    "SameSite is ignored when ignoring attributes"
+  );
+
 });
 
 QUnit.test("cookie parsing (legacy Firefox add-on)", function (assert) {
@@ -467,4 +486,88 @@ QUnit.test("getHostFromDomainInput", assert => {
   );
 });
 
+// Tests algorithm used in the pixel tracking heuristic
+// It should return a common substring between two given values
+QUnit.test("findCommonSubstrings", assert => {
+
+  assert.deepEqual(
+    utils.findCommonSubstrings('www.foo.bar', 'www.foob.ar'),
+    [],
+    "substrings under the length threshold of 8 are ignored"
+  );
+
+  assert.equal(
+    utils.findCommonSubstrings('foobar.com/foo/fizz/buzz/bar', 'foobar.com/foo/bizz/fuzz/bar')[0],
+    'foobar.com/foo/',
+    "returns longest matching value from the pair of URLs"
+  );
+
+  assert.deepEqual(
+    utils.findCommonSubstrings('foobar.com/fizz/buzz/bar/foo', 'foobar.com/fizzbuzz/buzz/bar/foo'),
+    ['foobar.com/fizz', "zz/buzz/bar/foo"],
+    "returns multiple substrings if multiple are present in comparison"
+  );
+
+});
+
+// used in pixel tracking heuristic, given a string the estimateMaxEntropy function
+// will return the estimated entropy value from it, based on logic parsing the string's length,
+// and classes of character complication included in the string
+QUnit.test("estimateMaxEntropy", assert => {
+  assert.equal(
+    utils.estimateMaxEntropy("google.com/analytics.google/analytics.google/google.com/analytics.google/analytics.google/google.com/analytics.google/analytics.google/google.com/analytics.google/analytics.google/google.com/analytics.google/analytics.google/google.com/analytics.google/anal"),
+    257,
+    "returns length of string if it's above 256 (MAX_LS_LEN_FOR_ENTROPY_EST)"
+  );
+
+  assert.equal(
+    utils.estimateMaxEntropy("googlecomanalytics"),
+    utils.estimateMaxEntropy("GOOGLECOMANALYTICS"),
+    "if the same string is all lower case or all upper case, the returned estimated entropy value is the same"
+  );
+
+  assert.notEqual(
+    utils.estimateMaxEntropy('analytics.GOOGLE1234_'),
+    utils.estimateMaxEntropy('ANALYTICS.google1234'),
+    "two nearly identical strings of mixed character classes and different cases will return different values"
+  );
+
+  assert.notEqual(
+    utils.estimateMaxEntropy('google.com/analytics'),
+    utils.estimateMaxEntropy('0191/_-goo~le9x+xzxo'),
+    "strings of the same length but from different character classes will estimate different entropy values"
+  );
+
+  assert.equal(
+    utils.estimateMaxEntropy("google.com/0191/_-google/analytics.fizz?buzz=foobar"),
+    320.55551316197466,
+    "entropy for complex string of varying character classes is correctly estimated"
+  );
+
+  assert.equal(
+    utils.estimateMaxEntropy("03899029.01_293"),
+    49.82892142331044,
+    "entropy for string from the common classes of characters is correctly estimated"
+  );
+
+  assert.equal(
+    utils.estimateMaxEntropy("fizzBUZZ012345"),
+    84,
+    "entropy for string from the case-insensitive class of characters is correctly estimated"
+  );
+
+  assert.equal(
+    utils.estimateMaxEntropy("fizz/buzz+fizzy~buzzy%"),
+    142.82076811925285,
+    "entropy for string from the case-sensitive class of characters is correctly estimated"
+  );
+
+  assert.equal(
+    utils.estimateMaxEntropy("1280x720") < 32,
+    true,
+    "resolution strings with 'x' char from SEPS class are correctly estimated as low entropy"
+  );
+
+});
+
 })();
